#!/usr/bin/env python

import os, sys, random
from qt import *

from testdialogbase import TestDialogBase
from testwin import TestWin

class TestDialog(TestDialogBase):
    Undecided = 2
    def __init__(self, parent = None):
        TestDialogBase.__init__(self, parent)
        self.connect(self.buttonMaybe, SIGNAL("clicked()"), self.setMaybeResult)

    def setMaybeResult(self):
        self.done(self.Undecided)


def loadTranslation(tf, dirs):
    trans = QTranslator(None)
    for d in dirs:
        if trans.load(tf, d):
            return trans

if __name__ == "__main__":
    app = QApplication(sys.argv)
    # prepare translation
    curdir = os.path.dirname(sys.argv[0])
    if not curdir:
        curdir = "."
    # check current locale
    loc = QTextCodec.locale()
    if loc != "C":
        # setup the searchpath for qt
        dirs = [curdir, "."]
        qtdir = os.getenv("QTDIR")
        if qtdir is not None:
            dirs.insert(-1, os.path.join(qtdir, "translations"))
        qtTrans = loadTranslation("qt_" + loc, dirs)
        if qtTrans:
            app.installTranslator(qtTrans)
        myTrans = loadTranslation("testapp_" + loc, dirs)
        if myTrans:
            app.installTranslator(myTrans)

    testDialog = TestDialog()
    r = testDialog.exec_loop()
    if r in (TestDialog.Accepted, TestDialog.Undecided):
        win = TestWin()
        app.setMainWidget(win)
        win.show()
        if r == TestDialog.Undecided:
            deadline = int(random.uniform(5000, 15000))
            qApp.mainWidget().statusBar().message(
                qApp.translate("TestApp", "Will terminate in %1 secs")
                               .arg(deadline / 1000.0, 0, "f", 1))
            QTimer.singleShot(deadline, win.close)
        sys.exit(app.exec_loop())
